package com.yeejoin.amos.boot.module.jg.biz.service;


import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yeejoin.amos.boot.biz.common.bo.ReginParams;
import com.yeejoin.amos.feign.systemctl.model.DictionarieValueModel;
import org.typroject.tyboot.core.restful.utils.ResponseModel;

import java.util.List;
import java.util.Map;

/**
 * 注册登记信息表接口类
 *
 * @author system_generator
 * @date 2023-08-17
 */
public interface IIdxBizJgRegisterInfoService {

    ResponseModel equipmentRegisterSubmit(Map<String, Object> paramMap);

    boolean batchDeleteByRecord(Map<String,Object> map);

    Map<String, Map<String, Object>> getEquipmentRegisterByRecord(String record, String isCopy);

    Page<JSONObject> queryForEquipmentRegisterPage(JSONObject jsonObject);

    Map<String, Object> getDetailByRecord(String record);

    Map<String, Object> getDetailFieldCamelCaseByRecord(String record);

    List<DictionarieValueModel> equCategoryListByCompanyType(ReginParams selectedOrgInfo, String equList);

    Page<JSONObject> queryForUnitEquipmentPage(JSONObject jsonObject);

    Page<JSONObject> queryEquipCanUsedByVesselPage(JSONObject jsonObject);
}
